## [PyKhmerNLP](https://metythornpenn.github.io/pykhmernlp/)

PyKhmerNLP is a library designed to process and analyze Khmer language data. It includes modules for working with addresses, dictionaries, and tokenization. This documentation will guide you through the functionalities of each module and provide examples to help you get s

## [Documentations](https://metythornpenn.github.io/pykhmernlp/)

Check out our details documentations [here](https://metythornpenn.github.io/pykhmernlp/)

## Installation

### Install from [PYPI](https://pypi.org/project/pykhmernlp/)

```shell
pip install pykhmernlp
```

### Install from Source

```shell
git clone https://github.com/MetythornPenn/pykhmernlp.git
cd pykhmernlp
pip install -e .
```

## Features

- Corpus
    + Khmer words
    + English Word
    + Khmer to Khmer Dictionary
    + English to English Dictionary
- Khmer Address
- Tokenizer
- Pronounce
- Tha


## Reference 

This library wraps around other awesome Khmer libraries. Without these other libraries, this library wouldn't exist.

Libraries:

- [khmercut](https://github.com/seanghay/tha): from seanghay
- [khmerpronounce](https://github.com/seanghay/khmerpronounce): from seanghay
- [tha](https://github.com/seanghay/tha): from seanghay

Datasets:

- [khmer words](https://github.com/unicode-org/icu): from unicode-org/icu